==> hlint-3.6.1-3-loong64.pkg.tar.zst: usr/share/haskell/register/hlint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hlint
version:              3.6.1
visibility:           public
id:                   hlint-3.6.1-6GS07GOt3HKJnCB3AOTWip
key:                  hlint-3.6.1-6GS07GOt3HKJnCB3AOTWip
license:              BSD-3-Clause
copyright:            Neil Mitchell 2006-2023
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/hlint#readme
synopsis:             Source code suggestions
description:          HLint gives suggestions on how to improve your source code.
category:             Development
abi:                  4c8102a5edd94d0a9ffccc7a6b94b1cd
exposed:              True
exposed-modules:      Language.Haskell.HLint
hidden-modules:
    Paths_hlint Apply CmdLine Extension Fixity HLint HsColour Idea
    Report Util Parallel Refact Timing CC EmbedData SARIF Summary
    Config.Compute Config.Haskell Config.Read Config.Type Config.Yaml
    GHC.All GHC.Util GHC.Util.ApiAnnotation GHC.Util.View
    GHC.Util.Brackets GHC.Util.DynFlags GHC.Util.FreeVars
    GHC.Util.HsDecl GHC.Util.HsExpr GHC.Util.SrcLoc GHC.Util.Scope
    GHC.Util.Unify Hint.All Hint.Bracket Hint.Comment Hint.Duplicate
    Hint.Export Hint.Extensions Hint.Fixities Hint.Import Hint.Lambda
    Hint.List Hint.ListRec Hint.Match Hint.Monad Hint.Naming
    Hint.NewType Hint.Pattern Hint.Pragma Hint.Restrict Hint.Smell
    Hint.Type Hint.Unsafe Hint.NumLiteral Test.All Test.Annotations
    Test.InputOutput Test.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hlint-3.6.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hlint-3.6.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hlint-3.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hlint
hs-libraries:         HShlint-3.6.1-6GS07GOt3HKJnCB3AOTWip
depends:
    aeson-2.2.0.0-Hqy1Zqe0ZE81dk2L20icmH
    ansi-terminal-1.1-IMcNZ5h2aza3c3hvu2tQms base-4.18.2.1
    bytestring-0.11.5.3 cmdargs-0.10.22-E2EkQI5shziHkHOdPiVHiM
    containers-0.6.7 cpphs-1.20.9.1-24V9xcsZlOA6VFsNCn4tMO
    data-default-0.7.1.3-Ihbp7WFUy146w4K1utdfXl
    deriving-aeson-0.2.10-ExvRlISIaOmEEfErLly2OI directory-1.3.8.5
    extra-1.7.16-1R70WzmZutyIjhcnCYje37
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    filepattern-0.1.3-CnPqHV4a9h44dqWTbzZWo9 ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-lib-parser-ex-9.6.0.2-F6iTYoppTkj3D0Lr6lBvsY
    hscolour-1.25-c2V5rD89ob6QNSiP65exR process-1.6.19.0
    refact-0.3.0.2-FJtsqxURVxtCj2G2lOYVeD text-2.0.2
    transformers-0.6.1.0 uniplate-1.6.13-6cQFcK4O53s462e3dy0IK1
    unordered-containers-0.2.20.1-1hrud2F05KV7Rz7RsKTZ5O
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    vector-0.13.2.0-DULMVARQ1CU3TLBOg9xkS6
    yaml-0.11.11.2-7sI7sa5XZN9728orpxXF0B

haddock-interfaces:   /usr/share/doc/hlint/html/hlint.haddock
haddock-html:         /usr/share/doc/hlint/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hlint-3.6-3.1-loong64.pkg.tar.zst: usr/share/haskell/register/hlint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hlint
version:              3.6
visibility:           public
id:                   hlint-3.6-AYkwZ12SFWNBJ4GT6RbrGu
key:                  hlint-3.6-AYkwZ12SFWNBJ4GT6RbrGu
license:              BSD-3-Clause
copyright:            Neil Mitchell 2006-2023
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/hlint#readme
synopsis:             Source code suggestions
description:          HLint gives suggestions on how to improve your source code.
category:             Development
abi:                  264ccca4709a9fbd200502aaabb591a9
exposed:              True
exposed-modules:      Language.Haskell.HLint
hidden-modules:
    Paths_hlint Apply CmdLine Extension Fixity HLint HsColour Idea
    Report Util Parallel Refact Timing CC EmbedData SARIF Summary
    Config.Compute Config.Haskell Config.Read Config.Type Config.Yaml
    GHC.All GHC.Util GHC.Util.ApiAnnotation GHC.Util.View
    GHC.Util.Brackets GHC.Util.DynFlags GHC.Util.FreeVars
    GHC.Util.HsDecl GHC.Util.HsExpr GHC.Util.SrcLoc GHC.Util.Scope
    GHC.Util.Unify Hint.All Hint.Bracket Hint.Comment Hint.Duplicate
    Hint.Export Hint.Extensions Hint.Fixities Hint.Import Hint.Lambda
    Hint.List Hint.ListRec Hint.Match Hint.Monad Hint.Naming
    Hint.NewType Hint.Pattern Hint.Pragma Hint.Restrict Hint.Smell
    Hint.Type Hint.Unsafe Hint.NumLiteral Test.All Test.Annotations
    Test.InputOutput Test.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hlint-3.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hlint-3.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hlint-3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hlint
hs-libraries:         HShlint-3.6-AYkwZ12SFWNBJ4GT6RbrGu
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    ansi-terminal-1.0.2-99kMoKqjfKvAwKECL4LpDt base-4.18.2.1
    bytestring-0.11.5.3 cmdargs-0.10.22-E2EkQI5shziHkHOdPiVHiM
    containers-0.6.7 cpphs-1.20.9.1-24V9xcsZlOA6VFsNCn4tMO
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    deriving-aeson-0.2.10-9mRt06kxycsDiiikvSSVIh directory-1.3.8.5
    extra-1.7.16-3o8MjPiNQTlLg74BSenHLy
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    filepattern-0.1.3-68iNgnGhWl0Lmdh6l8Oknh ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-lib-parser-ex-9.6.0.2-8X52mS6lbEo3Fw3qe9swLM
    hscolour-1.25-c2V5rD89ob6QNSiP65exR process-1.6.19.0
    refact-0.3.0.2-FJtsqxURVxtCj2G2lOYVeD text-2.0.2
    transformers-0.6.1.0 uniplate-1.6.13-3WatGBC3kLsu5Mf9WJ1JN
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    utf8-string-1.0.2-6mVuGO0K0TVHYD6zuQNk2y
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP
    yaml-0.11.11.2-GyIObvMByN0941lpfsiwCu

haddock-interfaces:   /usr/share/doc/hlint/html/hlint.haddock
haddock-html:         /usr/share/doc/hlint/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
